@@ -24,17 +24,14 @@ int main()
 	float samplingRate = 0.75;
 	mm.loadMTZ("1cbs_map.mtz", samplingRate);
 
-	// create a map for the bonds in this structure
-	pdb_redo::BondMap bm(structure);
-
 	// and finally collect the statistics
-	pdb_redo::EDIAStatsCollector collector(mm, structure, false, bm);
+	pdb_redo::EDIAStatsCollector collector(mm, structure, false);
 	auto r = collector.collect();
 
 	for (auto& ri: r)
 	{
 		// and do something with the data
-		std::cout << ri.EDIAm << std::endl;
+		std::cout << ri.EDIAm << '\n';
 	}
 
 	return 0;
