@@ -26,17 +26,16 @@
 
 #include <filesystem>
 #include <fstream>
-#include <iomanip>
 
 #include <clipper/clipper-ccp4.h>
 #include <clipper/clipper-contrib.h>
 
 #include <cif++.hpp>
+#include "cif++/gzio.hpp"
 
 #include "pdb-redo/ClipperWrapper.hpp"
 #include "pdb-redo/MapMaker.hpp"
 #include "pdb-redo/ResolutionCalculator.hpp"
-#include "pdb-redo/Statistics.hpp"
 
 #ifdef _MSC_VER
 #include <io.h>
@@ -283,7 +282,7 @@ bool IsMTZFile(const fs::path &p)
 {
 	bool result = false;
 
-	std::ifstream f(p);
+	cif::gzio::ifstream f(p);
 	if (f.is_open())
 	{
 		char sig[5] = {};
@@ -537,8 +536,6 @@ void MapMaker<FTYPE>::loadMTZ(const fs::path &f, float samplingRate,
 	if (not fs::exists(dataFile))
 		throw std::runtime_error("Could not open mtz file " + hklin.string());
 
-	const std::string kBasePath("/%s/%s/[%s]");
-
 	using clipper::CCP4MTZfile;
 
 	CCP4MTZfile mtzin;
@@ -569,31 +566,31 @@ void MapMaker<FTYPE>::loadMTZ(const fs::path &f, float samplingRate,
 	}
 
 	mtzin.import_hkl_data(mFbData,
-		cif::format(kBasePath, "*", "*", cif::join(fbLabels, ",")).str());
+		cif::format("/{}/{}/[{}]", "*", "*", cif::join(fbLabels, ",")));
 	mtzin.import_hkl_data(mFdData,
-		cif::format(kBasePath, "*", "*", cif::join(fdLabels, ",")).str());
+		cif::format("/{}/{}/[{}]", "*", "*", cif::join(fdLabels, ",")));
 	if (hasFAN)
 		mtzin.import_hkl_data(mFaData,
-			cif::format(kBasePath, "*", "*", cif::join(faLabels, ",")).str());
+			cif::format("/{}/{}/[{}]", "*", "*", cif::join(faLabels, ",")));
 	mtzin.import_hkl_data(mFoData,
-		cif::format(kBasePath, "*", "*", cif::join(foLabels, ",")).str());
+		cif::format("/{}/{}/[{}]", "*", "*", cif::join(foLabels, ",")));
 	mtzin.import_hkl_data(mFcData,
-		cif::format(kBasePath, "*", "*", cif::join(fcLabels, ",")).str());
+		cif::format("/{}/{}/[{}]", "*", "*", cif::join(fcLabels, ",")));
 
 	if (hasFREE)
 		mtzin.import_hkl_data(mFreeData,
-			cif::format(kBasePath, "*", "*", "FREE").str());
+			cif::format("/{}/{}/[{}]", "*", "*", "FREE"));
 
 	mtzin.import_hkl_data(mPhiFomData,
-		cif::format(kBasePath, "*", "*", "PHWT,FOM").str());
+		cif::format("/{}/{}/[{}]", "*", "*", "PHWT,FOM"));
 
 	mtzin.close_read();
 
 	if (dataFile != hklin)
 		fs::remove(dataFile);
 
-	Cell cell = mHKLInfo.cell();
-	Spacegroup spacegroup = mHKLInfo.spacegroup();
+	clipper::Cell cell = mHKLInfo.cell();
+	clipper::Spacegroup spacegroup = mHKLInfo.spacegroup();
 
 	ResolutionCalculator rc(cell);
 	mResHigh = 99;
@@ -715,7 +712,7 @@ void MapMaker<FTYPE>::loadFoFreeFromReflectionsFile(const fs::path &hklin)
 		"length_a", "length_b", "length_c", "angle_alpha", "angle_beta", "angle_gamma");
 
 	using clipper::Cell_descr;
-	Cell cell = Cell(Cell_descr{a, b, c, alpha, beta, gamma});
+	clipper::Cell cell(clipper::Cell_descr{ a, b, c, alpha, beta, gamma });
 
 	//	if (not cell2.equals(m_cell))
 	//		throw std::runtime_error("Reflections file and coordinates file do not agree upon the cell parameters");
@@ -739,8 +736,8 @@ void MapMaker<FTYPE>::loadFoFreeFromReflectionsFile(const fs::path &hklin)
 	}
 
 	std::string spacegroupDescr = reflns["symmetry"].front()["space_group_name_H-M"].as<std::string>();
-	auto spacegroup = Spacegroup(clipper::Spgr_descr{spacegroupDescr});
-	mHKLInfo = HKL_info(spacegroup, cell, clipper::Resolution{hires}, true);
+	auto spacegroup = clipper::Spacegroup(clipper::Spgr_descr{spacegroupDescr});
+	mHKLInfo = clipper::HKL_info(spacegroup, cell, clipper::Resolution{hires}, true);
 
 	//	m_crystal = MTZcrystal(m_xname, m_pname, m_cell);
 
@@ -791,23 +788,23 @@ void MapMaker<FTYPE>::loadFoFreeFromReflectionsFile(const fs::path &hklin)
 			first = false;
 		}
 
-		mFoData[ix] = F_sigF(F, sigF);
+		mFoData[ix] = clipper::data32::F_sigF(F, sigF);
 
 		switch (flag)
 		{
 			case 'o':
 			case 'h':
 			case 'l':
-				mFreeData[ix] = Flag(1);
+				mFreeData[ix] = clipper::data32::Flag(1);
 				break;
 
 			case 'f':
-				mFreeData[ix] = Flag(0);
+				mFreeData[ix] = clipper::data32::Flag(0);
 				break;
 
 			case '0':
 			case '1':
-				mFreeData[ix] = Flag(workRefl == flag ? 1 : 0);
+				mFreeData[ix] = clipper::data32::Flag(workRefl == flag ? 1 : 0);
 				break;
 
 			default:
@@ -827,20 +824,50 @@ void MapMaker<FTYPE>::loadFoFreeFromMTZFile(const fs::path &hklin,
 	if (cif::VERBOSE > 0)
 		std::cerr << "Recalculating maps from " << hklin << '\n';
 
-	const std::string kBasePath("/%s/%s/[%s]");
+	auto dataFile = hklin;
+
+	if (hklin.extension() == ".gz")
+	{
+		// file is compressed
+
+		fs::path p = hklin.parent_path();
+		std::string s = hklin.filename().string();
+
+		cif::gzio::ifstream in(hklin);
+
+		char tmpFileName[] = "/tmp/map-tmp-XXXXXX";
+		if (mkstemp(tmpFileName) < 0)
+			throw std::runtime_error(std::string("Could not create temp file for map: ") + strerror(errno));
+
+		dataFile = fs::path(tmpFileName);
+		std::ofstream out(dataFile);
+
+		if (not in.is_open() or not out.is_open())
+			throw std::runtime_error("Could not handle compressed map file");
+
+		out << in.rdbuf();
+	}
+
+	if (not fs::exists(dataFile))
+		throw std::runtime_error("Could not open map file " + hklin.string());
+
+	using namespace clipper;
 
 	using clipper::CCP4MTZfile;
 
 	CCP4MTZfile mtzin;
-	mtzin.open_read(hklin.string());
+	mtzin.open_read(dataFile.string());
 
 	mtzin.import_hkl_info(mHKLInfo);
 	mtzin.import_hkl_data(mFoData,
-		cif::format(kBasePath, "*", "*", cif::join(foLabels, ",")).str());
+		cif::format("/{}/{}/[{}]", "*", "*", cif::join(foLabels, ",")));
 	mtzin.import_hkl_data(mFreeData,
-		cif::format(kBasePath, "*", "*", cif::join(freeLabels, ",")).str());
+		cif::format("/{}/{}/[{}]", "*", "*", cif::join(freeLabels, ",")));
 
 	mtzin.close_read();
+
+	if (dataFile != hklin)
+		fs::remove(dataFile);
 }
 
 // --------------------------------------------------------------------
@@ -850,8 +877,8 @@ void MapMaker<FTYPE>::recalc(const cif::mm::structure &structure,
 	bool noBulk, AnisoScalingFlag anisoScaling,
 	float samplingRate, bool electronScattering)
 {
-	Cell cell = mHKLInfo.cell();
-	Spacegroup spacegroup = mHKLInfo.spacegroup();
+	auto cell = mHKLInfo.cell();
+	auto spacegroup = mHKLInfo.spacegroup();
 
 	// The calculation work
 	std::vector<clipper::Atom> atoms;
@@ -904,7 +931,7 @@ void MapMaker<FTYPE>::recalc(const cif::mm::structure &structure,
 	mFdData.init(mHKLInfo, cell);
 	mPhiFomData.init(mHKLInfo, cell);
 
-	HKL_data<Flag> flag(mHKLInfo, cell);
+	clipper::HKL_data<clipper::data32::Flag> flag(mHKLInfo, cell);
 
 	const int freeflag = 0;
 	for (auto ih = mFreeData.first(); not ih.last(); ih.next())
@@ -973,7 +1000,7 @@ void MapMaker<FTYPE>::recalc(const cif::mm::structure &structure,
 template <typename FTYPE>
 void MapMaker<FTYPE>::fixMTZ()
 {
-	Spacegroup spacegroup = mHKLInfo.spacegroup();
+	auto spacegroup = mHKLInfo.spacegroup();
 
 	enum
 	{
@@ -1134,7 +1161,7 @@ void MapMaker<FTYPE>::fixMTZ()
 
 		auto mFo = mFbData[ih] - mFdData[ih];
 
-		HKL_class cls(spacegroup, ih.hkl());
+		clipper::HKL_class cls(spacegroup, ih.hkl());
 
 		if (not mFoData[ih].missing() and mPhiFomData[ih].fom() > 0)
 		{
