@@ -24,14 +24,15 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "pdb-redo/ResolutionCalculator.hpp"
+#define _USE_MATH_DEFINES
+#include <cmath>
 
-#include "cif++/Point.hpp"
+#include "pdb-redo/ResolutionCalculator.hpp"
 
 namespace pdb_redo
 {
 
-using mmcif::kPI;
+const double kPI = M_PI;
 
 ResolutionCalculator::ResolutionCalculator(const clipper::Cell &cell)
 	: ResolutionCalculator(cell.a(), cell.b(), cell.c(),
@@ -44,7 +45,7 @@ ResolutionCalculator::ResolutionCalculator(const clipper::Cell &cell)
 ResolutionCalculator::ResolutionCalculator(double a, double b, double c,
 	double alpha, double beta, double gamma)
 {
-	double deg2rad = atan(1.0) / 45.0;
+	double deg2rad = std::atan(1.0) / 45.0;
 
 	double ca = std::cos(deg2rad * alpha);
 	double sa = std::sin(deg2rad * alpha);
